summaryrefslogtreecommitdiff
path: root/addons/web/static/lib/jquery.mjs.nestedSortable/jquery.mjs.nestedSortable.js
diff options
context:
space:
mode:
authorNicolas Lempereur <nle@odoo.com>2017-09-20 16:57:40 +0200
committerArnold Moyaux <arm@odoo.com>2017-12-21 09:59:51 +0100
commitf771a9d94592fae0f30672a2800f38a3883fb69d (patch)
tree55d5f2786d9f10f22345fa0e676da1b1e29a420b /addons/web/static/lib/jquery.mjs.nestedSortable/jquery.mjs.nestedSortable.js
parent1ffe85f1cb3defcbf932138e2fc13f3a81b34787 (diff)
[FIX] stock_account: stock_history slow read_group
The stock_history view is generated from by grouping of move from sources and move to destinations which depending on the request and number of request can be rather slow. This fix replace a possibly high number of request by a slower number. On a production instance, doing an inventory at a choosen date: - with 300 stock moves, went from 4 minutes to 4 seconds, - with 130 000 stock moves, went from 66 minutes to 10 minutes opw-765793 closes #19594
Diffstat (limited to 'addons/web/static/lib/jquery.mjs.nestedSortable/jquery.mjs.nestedSortable.js')
0 files changed, 0 insertions, 0 deletions